@@ -2,6 +2,9 @@ public class Main {
     public static void main(String[] args) throws Exception {
         // invocation of void method. verify that it runs without error
         Foo.hello();
+        Foo.hello2();
+        Foo.unbox();
+        Foo.box();
 
         Object o = new Foo().getMessage();
         assertEquals(args[0],o);
